@@ -166,12 +166,18 @@ class GQLHandler:
         return (await self.runAuthorizedGqlQuery_a(gq.QUERY['watchLastLocateQ'], { "uid": ownId }))['data']
 
     def trackWatch(self, ownId): # tracking time - seconds
-        res = self.runAuthorizedGqlQuery_a(gq.QUERY['trackWatchQ'], { "uid": ownId })['data']
+        res = self.runAuthorizedGqlQuery(gq.QUERY['trackWatchQ'], { "uid": ownId })['data']
         if res['trackWatch'] != None:
             return res
         return { 'trackWatch': -1 }
 
-    async def askWatchLocate(self, ownId):
+    def askWatchLocate(self, ownId):
+        res = self.runAuthorizedGqlQuery(gq.QUERY['askWatchLocateQ'], { "uid": ownId })['data']
+        if res['askWatchLocate'] != None:
+            return res
+        return { 'askWatchLocate': False }
+
+    async def askWatchLocate_a(self, ownId):
         res = (await self.runAuthorizedGqlQuery_a(gq.QUERY['askWatchLocateQ'], { "uid": ownId }))['data']
         if res['askWatchLocate'] != None:
             return res
